Package: compost
Version: 0.2.0
Title: Video Compositing via 'FFmpeg'
Description: Wraps common 'FFmpeg' <https://ffmpeg.org/> filter_complex
    patterns (overlay, chromakey, concat, scale, vstack) into clean R
    functions for video compositing, and lowers an 'OpenTimelineIO'
    <https://github.com/AcademySoftwareFoundation/OpenTimelineIO> timeline
    (via the 'rotio' package) to a
    rendered video.
Authors@R: c(
    person("Troy", "Hernandez",
        email = "troy@cornball.ai",
        role = c("aut", "cre"),
        comment = c(ORCID = "0009-0005-4248-604X")),
    person("cornball.ai", role = "cph"))
License: MIT + file LICENSE
URL: https://github.com/cornball-ai/compost
BugReports: https://github.com/cornball-ai/compost/issues
Encoding: UTF-8
SystemRequirements: ffmpeg (>= 5.0)
Imports: rotio
Suggests: tinytest
NeedsCompilation: no
Packaged: 2026-07-24 21:32:46 UTC; troy
Author: Troy Hernandez [aut, cre] (ORCID:
    <https://orcid.org/0009-0005-4248-604X>),
  cornball.ai [cph]
Maintainer: Troy Hernandez <troy@cornball.ai>
Repository: CRAN
Date/Publication: 2026-08-04 14:00:08 UTC
Built: R 4.6.0; ; 2026-08-04 16:03:21 UTC; unix
